// UVa 196
// On fait un tri topologique en parcourant le graphe pour dterminer
// quelles cellules valuer en premier. Puis on met  jour les valeurs des
// cellules. Faire attention  la taille (inconnue) de l'entre : mieux
// vaut des allocations dynamiques.

#include <iostream>
#include <stdlib.h>
#include <string.h>

#define SIZE_FILE 1000 // taille de depart de la file de sommets
#define MAX_SIZE_CELL 1000 // nb max de char dans une cellule

struct cellule
{
  bool traite;
  int valeur;
  int *peres;
  int nb_peres_non_traites;
  int taille_peres;
  int *fils;
  int taille_fils;
};

cellule * tableau = NULL;
int l, h; // dimensions du tableau
int taille; // taille totale du tableau (l*h)
int * file;
int taille_file = SIZE_FILE;
int debut_file, fin_file;
char cell[MAX_SIZE_CELL];
int * nombre_fils = NULL;


// nom des colonnes --> numero
int lettres_to_int(char *s, int n)
{
  int x=0;
  for (int i=0; i<n; ++i)
    x = 26*x+(s[i]-'A'+1);
  return x;
}

// compter le nombre de dependances (taille de peres)
int nombre_peres()
{
  int i=0;
  int nombre=0;
  while(cell[i] != '\0')
    {
      if (cell[i] == '=' || cell[i] == '+')
	++nombre;
      ++i;
    }
  return nombre;
}

// augmenter la taille de la file si elle est pleine
void augmente_file()
{
  taille_file *= 2;
  file = (int *) realloc(file, taille_file*sizeof(int));
}

// lire la cellule x, mettre a jour les peres
void lire_cellule(int x)
{
  std::cin >> cell;
  tableau[x].taille_peres=0;
  tableau[x].taille_fils=0;
  tableau[x].traite=false;
  tableau[x].nb_peres_non_traites=0;
  tableau[x].valeur=0;
  tableau[x].fils=NULL;
  tableau[x].peres=NULL;

  if (cell[0]!='=')
    {
      tableau[x].valeur = atoi(cell);
      tableau[x].traite=true;
      ++fin_file;
      if (fin_file >= taille_file)
	augmente_file();
      file[fin_file]=x;
      return;
    }

  // mise a jour de peres
  int i=0;
  int debut, longueur;
  int ligne, colonne;
  int nbp = nombre_peres();
  tableau[x].peres = (int *) malloc(nbp*sizeof(int));
  while (cell[i] != '\0')
    {
      ++i; // manger le '=' ou le '+'
      debut=i;
      while (cell[i] >= 'A' && cell[i] <= 'Z')
	++i;
      longueur=i-debut;
      colonne=lettres_to_int(&cell[debut], longueur);
      ligne=0;
      while (cell[i] >= '0' && cell[i] <= '9')
	{
	  ligne = 10*ligne+cell[i]-'0';
	  ++i;
	}
      --ligne; --colonne;
      tableau[x].peres[tableau[x].taille_peres]=l*ligne+colonne;
      ++tableau[x].taille_peres;
      ++nombre_fils[ligne*l+colonne];
    }
}

// mettre a jour les fils et nb_peres_non_traites
void maj_fils()
{
  int x;
  for (int t=0; t<taille; ++t)
    if (nombre_fils[t] > 0)
      tableau[t].fils = (int *)malloc(nombre_fils[t]*sizeof(int));
  
  for (int t=0; t<taille; ++t)
    for (int k=0; k<tableau[t].taille_peres; ++k)
      {
	x = tableau[t].peres[k];
	tableau[x].fils[tableau[x].taille_fils] = t;
	++tableau[x].taille_fils;
	++tableau[t].nb_peres_non_traites;
      }
}


void nettoie(int h1, int l1)
{
  for (int t=0; t<l1*h1; ++t)
    {
      free(tableau[t].peres);
      free(tableau[t].fils);
    }
  free(tableau);
  free(nombre_fils);

}

int main()
{
  int n;
  int nb_fils;
  int l_ancien=0, h_ancien=0;
  int t, t1;

  file = (int *) malloc(taille_file*sizeof(int));

  std::cin >> n;

  std::cin >> l >> h;

  for (int i=0; i<n; ++i)
    {
      taille = l*h;
      // initialisation
      debut_file = 0;
      fin_file = -1;
      if (taille > l_ancien * h_ancien)
	{
	  nettoie(l_ancien, h_ancien);
	  tableau = (cellule *) malloc(taille*sizeof(cellule));
	  nombre_fils = (int *) calloc(taille,sizeof(int));
	}
      else
	memset(nombre_fils, 0, taille);

      // lecture de la feuille de calcul
      for (int j=0; j<taille; ++j)
	lire_cellule(j);
      maj_fils();

      // tri topologique
      while (fin_file >= debut_file)
	{
	  t = file[debut_file];
	  nb_fils = tableau[t].taille_fils;
	  for (int j=0; j<nb_fils; ++j)
	    {
	      t1 = tableau[t].fils[j];
	      --tableau[t1].nb_peres_non_traites;
	      tableau[t1].valeur += tableau[t].valeur;
	      if (tableau[t1].nb_peres_non_traites < 1)
		{
		  tableau[t1].traite = true;
		  ++fin_file;
		  if (fin_file >= taille_file)
		    augmente_file();
		  file[fin_file] = t1;
		}
	    }
	  ++debut_file;
	}

      // affichage
      for (int j=0; j<h; ++j)
	{
	  for (int k=0; k<l-1; ++k)
	    std::cout << tableau[j*l+k].valeur << ' ';
	  std::cout << tableau[j*l+l-1].valeur << std::endl;
	}

      l_ancien = l;
      h_ancien = h;
      std::cin >> l >> h;

    }
}
