// UVa 10416
// Un axe de symtrie passe (selon la parit du nombre de sommets)
// soit par deux sommets opposs, soit par deux
// milieux opposs, soit par un sommet et le milieu oppos.
// Un sommet est envoy sur le sommet "symtrique".
// On parcours le polygone sommet par sommet, on teste sommet par sommet
// si la droite correspondante est axe de symtrie.
// Il est mieux d'eviter les divisions, voire de ne travailler qu'avec
// des entiers ; ici on pourrait mais on perdrait en lisibilite.

#include <iostream>

#define EPSILON 0.00001 // marge d'erreur

bool egal(float x, float y)
{
  return (x-EPSILON <= y && y <= x+EPSILON);
}

// (x2,y2) est-il le symetrique de (x1,y1) par rapport a la droite
// passant par (s1,t1) et (s2,t2) ?
bool symetrie(float s1, float t1, float s2, float t2,
	      float x1, float y1, float x2, float y2)
{
  // si droite verticale
  if (egal(s1,s2))
    return (egal(y1,y2) && egal(x1-s1,s1-x2));

  // cas general
  // calcul eq droite y=ax+b
  float a = (t2-t1)/(s2-s1);
  float b = t1-a*s1;
  float lambda = 2*(y1-a*x1-b)/(1+a*a);
  return (egal(x1+lambda*a, x2) && egal(y1-lambda, y2));

}

int main()
{
  int n;
  int nb_cotes;

  float poly[101][2];

  std::cin >> n;
  for (int i=0; i<n; ++i)
    {
      std::cin >> nb_cotes;
      for (int j=0; j<nb_cotes; ++j)
	std::cin >> poly[j][0] >> poly[j][1];
      bool symetrique = false;
      bool sym_loc;
      if (nb_cotes % 2 == 0)
	for (int j=0; j<nb_cotes/2; ++j)
	  {
	    if (symetrique) break;
	    sym_loc=true;
	    for (int k=j+1; k<j+nb_cotes/2; ++k)
	      sym_loc = sym_loc &&
		symetrie(poly[j][0],poly[j][1],
			 poly[j+nb_cotes/2][0],poly[j+nb_cotes/2][1],
			 poly[k][0],poly[k][1],
			 poly[(2*j-k+nb_cotes)%nb_cotes][0],
			 poly[(2*j-k+nb_cotes)%nb_cotes][1]);
	    symetrique = symetrique || sym_loc;
	    if (symetrique) break;
	    sym_loc=true;
	    for (int k=j+1; k<j+1+nb_cotes/2; ++k)
	      sym_loc = sym_loc &&
		symetrie((poly[j][0]+poly[j+1][0])/2,
			 (poly[j][1]+poly[j+1][1])/2,
			 (poly[j+nb_cotes/2][0]+
			  poly[(1+j+nb_cotes/2)%nb_cotes][0])/2,
			 (poly[j+nb_cotes/2][1]+
			  poly[(1+j+nb_cotes/2)%nb_cotes][1])/2,
			 poly[k%nb_cotes][0],poly[k%nb_cotes][1],
			 poly[(2*j-k+nb_cotes+1)%nb_cotes][0],
			 poly[(2*j-k+nb_cotes+1)%nb_cotes][1]);
	    symetrique = symetrique || sym_loc;
	  }
      else // nb_cote est impair
	for (int j=0; j<nb_cotes; ++j)
	  {
	    if (symetrique) break;
	    sym_loc = true;
	    for (int k=j+1; k<j+1+nb_cotes/2; ++k)
	      sym_loc = sym_loc &&
		symetrie(poly[j][0],poly[j][1],
			 (poly[(j+nb_cotes/2)%nb_cotes][0]+
			  poly[(1+j+nb_cotes/2)%nb_cotes][0])/2,
			 (poly[(j+nb_cotes/2)%nb_cotes][1]+
			  poly[(1+j+nb_cotes/2)%nb_cotes][1])/2,
			 poly[k%nb_cotes][0],poly[k%nb_cotes][1],
			 poly[(2*j-k+nb_cotes)%nb_cotes][0],
			 poly[(2*j-k+nb_cotes)%nb_cotes][1]);
	    symetrique = symetrique || sym_loc;
	  }
  if (symetrique)
    std::cout << "Yes" << std::endl;
  else
    std::cout << "No" << std::endl;
    }
}
